@@ -18,6 +18,7 @@ type CommandType TokenType
 var CommandTypes = []CommandType{ //nolint: deadcode
 	BACKSPACE,
 	CTRL,
+	ALT,
 	DOWN,
 	ENTER,
 	ESCAPE,
@@ -72,6 +73,7 @@ var CommandFuncs = map[CommandType]CommandFunc{
 	SLEEP:     ExecuteSleep,
 	TYPE:      ExecuteType,
 	CTRL:      ExecuteCtrl,
+	ALT:       ExecuteAlt,
 	ILLEGAL:   ExecuteNoop,
 }
 
@@ -102,7 +104,7 @@ func (c Command) Execute(v *VHS) {
 // ExecuteNoop is a no-op command that does nothing.
 // Generally, this is used for Unknown commands when dealing with
 // commands that are not recognized.
-func ExecuteNoop(c Command, v *VHS) {}
+func ExecuteNoop(_ Command, _ *VHS) {}
 
 // ExecuteKey is a higher-order function that returns a CommandFunc to execute
 // a key press for a given key. This is so that the logic for key pressing
@@ -139,8 +141,20 @@ func ExecuteCtrl(c Command, v *VHS) {
 	_ = v.Page.Keyboard.Release(input.ControlLeft)
 }
 
+// ExecuteAlt is a CommandFunc that presses the argument key with the alt key
+// held down on the running instance of vhs.
+func ExecuteAlt(c Command, v *VHS) {
+	_ = v.Page.Keyboard.Press(input.AltLeft)
+	for _, r := range c.Args {
+		if k, ok := keymap[r]; ok {
+			_ = v.Page.Keyboard.Type(k)
+		}
+	}
+	_ = v.Page.Keyboard.Release(input.AltLeft)
+}
+
 // ExecuteHide is a CommandFunc that starts or stops the recording of the vhs.
-func ExecuteHide(c Command, v *VHS) {
+func ExecuteHide(_ Command, v *VHS) {
 	v.PauseRecording()
 }
 
@@ -154,13 +168,13 @@ func ExecuteRequire(c Command, v *VHS) {
 }
 
 // ExecuteShow is a CommandFunc that resumes the recording of the vhs.
-func ExecuteShow(c Command, v *VHS) {
+func ExecuteShow(_ Command, v *VHS) {
 	v.ResumeRecording()
 }
 
 // ExecuteSleep sleeps for the desired time specified through the argument of
 // the Sleep command.
-func ExecuteSleep(c Command, v *VHS) {
+func ExecuteSleep(c Command, _ *VHS) {
 	dur, err := time.ParseDuration(c.Args)
 	if err != nil {
 		return
@@ -218,6 +232,11 @@ var Settings = map[string]CommandFunc{
 	"Width":         ExecuteSetWidth,
 	"Shell":         ExecuteSetShell,
 	"LoopOffset":    ExecuteLoopOffset,
+	"MarginFill":    ExecuteSetMarginFill,
+	"Margin":        ExecuteSetMargin,
+	"WindowBar":     ExecuteSetWindowBar,
+	"WindowBarSize": ExecuteSetWindowBarSize,
+	"BorderRadius":  ExecuteSetBorderRadius,
 }
 
 // ExecuteSet applies the settings on the running vhs specified by the
@@ -259,14 +278,13 @@ func ExecuteSetWidth(c Command, v *VHS) {
 func ExecuteSetShell(c Command, v *VHS) {
 	if s, ok := Shells[c.Args]; ok {
 		v.Options.Shell = s
-	} else {
-		v.Options.Shell.Prompt = ""
-		v.Options.Shell.Command = c.Args
 	}
 }
 
-const bitSize = 64
-const base = 10
+const (
+	bitSize = 64
+	base    = 10
+)
 
 // ExecuteSetLetterSpacing applies letter spacing (also known as tracking) on
 // the vhs.
@@ -295,6 +313,7 @@ func ExecuteSetTheme(c Command, v *VHS) {
 	bts, _ := json.Marshal(v.Options.Theme)
 	_, _ = v.Page.Eval(fmt.Sprintf("() => term.options.theme = %s", string(bts)))
 	v.Options.Video.BackgroundColor = v.Options.Theme.Background
+	v.Options.Video.WindowBarColor = v.Options.Theme.Background
 }
 
 // ExecuteSetTypingSpeed applies the default typing speed on the vhs.
@@ -338,6 +357,31 @@ func ExecuteLoopOffset(c Command, v *VHS) {
 	v.Options.LoopOffset = loopOffset
 }
 
+// ExecuteSetMarginFill sets vhs margin fill
+func ExecuteSetMarginFill(c Command, v *VHS) {
+	v.Options.Video.MarginFill = c.Args
+}
+
+// ExecuteSetMargin sets vhs margin size
+func ExecuteSetMargin(c Command, v *VHS) {
+	v.Options.Video.Margin, _ = strconv.Atoi(c.Args)
+}
+
+// ExecuteSetWindowBar sets window bar type
+func ExecuteSetWindowBar(c Command, v *VHS) {
+	v.Options.Video.WindowBar = c.Args
+}
+
+// ExecuteSetWindowBar sets window bar size
+func ExecuteSetWindowBarSize(c Command, v *VHS) {
+	v.Options.Video.WindowBarSize, _ = strconv.Atoi(c.Args)
+}
+
+// ExecuteSetWindowBar sets corner radius
+func ExecuteSetBorderRadius(c Command, v *VHS) {
+	v.Options.Video.BorderRadius, _ = strconv.Atoi(c.Args)
+}
+
 func getTheme(s string) (Theme, error) {
 	if strings.TrimSpace(s) == "" {
 		return DefaultTheme, nil
