@@ -261,6 +261,16 @@ func TestLexTapeFile(t *testing.T) {
 		{CTRL, "Ctrl"},
 		{PLUS, "+"},
 		{STRING, "R"},
+		{COMMENT, " Alt:"},
+		{ALT, "Alt"},
+		{PLUS, "+"},
+		{STRING, "."},
+		{ALT, "Alt"},
+		{PLUS, "+"},
+		{STRING, "L"},
+		{ALT, "Alt"},
+		{PLUS, "+"},
+		{STRING, "i"},
 		{COMMENT, " Display:"},
 		{HIDE, "Hide"},
 		{SHOW, "Show"},
