@@ -41,6 +41,9 @@ The following is a list of all possible commands in VHS:
 * %PageDown% [repeat]
 * %Hide%
 * %Show%
+* %Escape%
+* %Alt%+<key>
+* %Space% [repeat]
 `
 
 	manOutput = `The Output command instructs VHS where to save the output of the recording.
@@ -75,7 +78,7 @@ var manCmd = &cobra.Command{
 	Short:   "Generate man pages",
 	Args:    cobra.NoArgs,
 	Hidden:  true,
-	RunE: func(cmd *cobra.Command, args []string) error {
+	RunE: func(_ *cobra.Command, _ []string) error {
 		if isatty.IsTerminal(os.Stdout.Fd()) {
 			renderer, err := glamour.NewTermRenderer(
 				glamour.WithStyles(GlamourTheme),
