@@ -14,9 +14,9 @@ import (
 	"time"
 
 	"github.com/caarlos0/env/v6"
+	"github.com/charmbracelet/ssh"
 	"github.com/charmbracelet/wish"
 	"github.com/charmbracelet/wish/logging"
-	"github.com/gliderlabs/ssh"
 	"github.com/spf13/cobra"
 )
 
@@ -37,7 +37,7 @@ type config struct {
 var serveCmd = &cobra.Command{
 	Use:   "serve",
 	Short: "Start the VHS SSH server",
-	RunE: func(cmd *cobra.Command, args []string) error {
+	RunE: func(cmd *cobra.Command, _ []string) error {
 		var cfg config
 		if err := env.Parse(&cfg, env.Options{
 			Prefix: "VHS_",
@@ -96,13 +96,13 @@ var serveCmd = &cobra.Command{
 							var gif, mp4, webm string
 							switch {
 							case v.Options.Video.Output.MP4 != "":
-								tempFile += ".mp4"
+								tempFile += mp4
 								mp4 = tempFile
 							case v.Options.Video.Output.WebM != "":
-								tempFile += ".webm"
+								tempFile += webm
 								webm = tempFile
 							default:
-								tempFile += ".gif"
+								tempFile += gif
 								gif = tempFile
 							}
 							v.Options.Video.Output.GIF = gif
