@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"log"
 	"math"
 	"os"
 	"os/exec"
@@ -13,8 +14,8 @@ import (
 	"time"
 
 	"github.com/go-rod/rod"
-	"github.com/go-rod/rod/lib/input"
 	"github.com/go-rod/rod/lib/launcher"
+	"github.com/go-rod/rod/lib/proto"
 )
 
 // VHS is the object that controls the setup.
@@ -26,6 +27,7 @@ type VHS struct {
 	TextCanvas   *rod.Element
 	CursorCanvas *rod.Element
 	mutex        *sync.Mutex
+	started      bool
 	recording    bool
 	tty          *exec.Cmd
 	totalFrames  int
@@ -83,38 +85,65 @@ func DefaultVHSOptions() Options {
 
 // New sets up ttyd and go-rod for recording frames.
 func New() VHS {
-	port := randomPort()
-	tty := StartTTY(port)
-	go tty.Run() //nolint:errcheck
-
-	opts := DefaultVHSOptions()
-	path, _ := launcher.LookPath()
-	enableNoSandbox := os.Getenv("VHS_NO_SANDBOX") != ""
-	u := launcher.New().Leakless(false).Bin(path).NoSandbox(enableNoSandbox).MustLaunch()
-	browser := rod.New().ControlURL(u).MustConnect()
-	page := browser.MustPage(fmt.Sprintf("http://localhost:%d", port))
-
 	mu := &sync.Mutex{}
-
+	opts := DefaultVHSOptions()
 	return VHS{
 		Options:   &opts,
-		Page:      page,
-		browser:   browser,
-		tty:       tty,
 		recording: true,
 		mutex:     mu,
-		close:     browser.Close,
 	}
 }
 
+// Start starts ttyd, browser and everything else needed to create the gif.
+func (vhs *VHS) Start() error {
+	vhs.mutex.Lock()
+	defer vhs.mutex.Unlock()
+
+	if vhs.started {
+		return fmt.Errorf("vhs is already started")
+	}
+
+	port := randomPort()
+	vhs.tty = buildTtyCmd(port, vhs.Options.Shell)
+	if err := vhs.tty.Start(); err != nil {
+		return fmt.Errorf("could not start tty: %w", err)
+	}
+
+	path, _ := launcher.LookPath()
+	enableNoSandbox := os.Getenv("VHS_NO_SANDBOX") != ""
+	u, err := launcher.New().Leakless(false).Bin(path).NoSandbox(enableNoSandbox).Launch()
+	if err != nil {
+		return fmt.Errorf("could not launch browser: %w", err)
+	}
+	browser := rod.New().ControlURL(u).MustConnect()
+	page, err := browser.Page(proto.TargetCreateTarget{URL: fmt.Sprintf("http://localhost:%d", port)})
+	if err != nil {
+		return fmt.Errorf("could not open ttyd: %w", err)
+	}
+
+	vhs.browser = browser
+	vhs.Page = page
+	vhs.close = vhs.browser.Close
+	vhs.started = true
+	return nil
+}
+
 // Setup sets up the VHS instance and performs the necessary actions to reflect
 // the options that are default and set by the user.
 func (vhs *VHS) Setup() {
 	// Set Viewport to the correct size, accounting for the padding that will be
 	// added during the render.
 	padding := vhs.Options.Video.Padding
-	width := vhs.Options.Video.Width - padding - padding
-	height := vhs.Options.Video.Height - padding - padding
+	margin := 0
+	if vhs.Options.Video.MarginFill != "" {
+		margin = vhs.Options.Video.Margin
+	}
+	bar := 0
+	if vhs.Options.Video.WindowBar != "" {
+		bar = vhs.Options.Video.WindowBarSize
+	}
+	width := vhs.Options.Video.Width - double(padding) - double(margin)
+	height := vhs.Options.Video.Height - double(padding) - double(margin) - bar
 	vhs.Page = vhs.Page.MustSetViewport(width, height, 0, false)
 
 	// Let's wait until we can access the window.term variable.
@@ -124,19 +153,6 @@ func (vhs *VHS) Setup() {
 	vhs.TextCanvas, _ = vhs.Page.Element("canvas.xterm-text-layer")
 	vhs.CursorCanvas, _ = vhs.Page.Element("canvas.xterm-cursor-layer")
 
-	// Set up the Prompt
-	shellCommand := fmt.Sprintf(vhs.Options.Shell.Command, vhs.Options.Shell.Prompt)
-	if vhs.Options.Shell.Prompt == "" {
-		shellCommand = vhs.Options.Shell.Command
-	}
-	vhs.Page.MustElement("textarea").
-		MustInput(shellCommand).
-		MustType(input.Enter)
-
-	vhs.Page.MustElement("textarea").
-		MustInput(vhs.Options.Shell.Clear).
-		MustType(input.Enter)
-
 	// Apply options to the terminal
 	// By this point the setting commands have been executed, so the `opts` struct is up to date.
 	vhs.Page.MustEval(fmt.Sprintf("() => { term.options = { fontSize: %d, fontFamily: '%s', letterSpacing: %f, lineHeight: %f, theme: %s } }",
@@ -194,14 +210,14 @@ func (vhs *VHS) Render() error {
 		}
 		out, err := cmd.CombinedOutput()
 		if err != nil {
-			fmt.Println(string(out))
+			log.Println(string(out))
 		}
 	}
 
 	return nil
 }
 
-// Apply Loop Offset by modifying frame sequence
+// ApplyLoopOffset by modifying frame sequence
 func (vhs *VHS) ApplyLoopOffset() error {
 	if vhs.totalFrames <= 0 {
 		return errors.New("no frames")
